@@ -1,11 +1,15 @@
 import logging
 import numpy as np
 from sparrow.version_ops import VersionControl
-from sparrow.color_str import *
+from sparrow.color.constant import *
 from sparrow.core import *
-from sparrow.decorator import *
+from sparrow.string.color_string import rgb_string
+from sparrow.decorators import *
+from sparrow.string.color_string import rgb_string
 from sparrow.time import *
 import time
+
+
 # vc = VersionControl("sparrow-tool")
 # vc.update_version(1)
 
@@ -19,6 +23,7 @@ def function(n):
     time.sleep(0.1)
     return s
 
+
 if __name__ == "__main__":
     print(rgb_string("hello rgb string", YELLOW))
     print(rgb_string("hello rgb string", GREEN))
